# Activity

- psf/black repo issues and pull requests

  - FEAT: Add `-> None` to any typed `__init__()` #2913 [NickCrews] T: enhancement R: rejected

    Is your feature request related to a problem? Please describe. In pandas-dev/pandas#46279 someone wants to make the...

    - NickCrews: Thank you!

  - Finish "magic trailing comma" handling #1288 [ambv] T: bug

    #826 introduced the concept of a magic trailing comma: if you, the programmer, explicitly put a trailing comma in a...

    - dariocurr: Is there the possibility to set that the magic final comma must always be used? I mean, is there...

    - ggabriel96: Is there the possibility to set that the magic final comma must always be used? I mean, is there...

    - utkarshgupta137: Is there the possibility to set that the magic final comma must always be used? I mean, is there...

  - Trailing comma in a dict in function call split all parameters #2672 [char101] T: design F: linebreak

    Describe the style change When passing dict as a function parameter I often prefer than the dict is split in...

    - ehiggs: This is a regression somewhere between 19.10b0 and 22.1.0 and affects a lot of users using...

    - JelleZijlstra: @ehiggs that's the magic trailing comma, which for better or for worse is Black's documented...

  - Enable `--experimental-string-processing` to be default #2188 [cooperlees] T: enhancement T: design S: accepted F: strings / docstrings

    Lets move CI + then the default of black to use the --experimental-string-processing behavior. Today, if enabled on...

    - bbugyi200: @ajoino See #1132 (comment) and surrounding comments for a previous discussion on this. As I...

    - ajoino: @bbugyi200 Thank you for the link and your impressive work. I agree that this is a minor...

    - bbugyi200: @ajoino Ahh, I see. I agree with you on this point: Aligning the quotation marks seems desirable...

  - feat(config): Support `--config` in pyproject.toml #2525 [Shivansh-007] C: command line / config

    Description You can now specify config key in pyproject.toml which does the same job as the CLI option --config. The...

  - Line too long: Comments #1713 [anirudnits] T: design F: comments F: linetoolong

    Problem Consider the below comment: # this comment is longer than what is specified in line length arguments passed...

    - earonesty: i agree, black behaves very oddly with comments while small_cond: # long comment here... ...

  - When detecting Python versions, `f"{x=}"` should imply 3.8+ #2907 [Zac-HD] T: enhancement S: accepted C: parser C: target version

    Describe the bug The = specifier was added to f-strings in Python 3.8, but Black does not yet distinguish it from...

    - ichard26: I'm tentatively accepting this assuming it's technically feasible with iter_fexpr_spans. Hopefully it is.

  - Horizontally align quotes in multi-line f-string breaks #2915 [ajoino] T: design F: strings / docstrings F: linebreak

    Describe the style change Align quotation marks for multi-line string breaks (using --preview) if the resulting...

    - JelleZijlstra: I don't think we should do this, it creates inconsistent indentation. I have never seen this...

    - ajoino: The argument for aligning the quotes stems from how you split f-strings. I usually keep all...

    - TylerYep: There are currently popular open-source linters that have rules against inconsistent indentation...

  - Add improved docstring processing #2885 [TomFryers]

    Description One of the things discussed in issue #144 was quote placement. Reading through the discussion, there...

  - Use parentheses with equality check in walrus/assignment statements #2770 [Shivansh-007]

    Closes #449 Checklist - did you ... Add a CHANGELOG entry if necessary? Add / update tests if necessary? Add new...